'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var react = require('react');
var globalEventTarget = require('global-event-target');

/** Provides a declarative addEventListener */

var useEventListener = function useEventListener(
/** eventName - The name of the event. */
eventName,
/** A function that handles the event or an object implementing the `EventListener` interface. */
handler,
/** A optional object containing `element`, `capture`, `passive`, and `once`. */
options) {
  if (options === void 0) {
    options = {};
  }

  var savedHandlerRef = react.useRef();
  var _options = options,
      _options$element = _options.element,
      element = _options$element === void 0 ? globalEventTarget.globalEventTarget : _options$element,
      capture = _options.capture,
      passive = _options.passive,
      once = _options.once;
  react.useEffect(function () {
    savedHandlerRef.current = handler;
  }, [handler]);
  react.useEffect(function () {
    var isSupported = element && element.addEventListener;

    if (!isSupported) {
      return;
    }

    var eventListener = function eventListener(evt) {
      var event = evt;

      if (savedHandlerRef.current.hasOwnProperty('handleEvent')) {
        savedHandlerRef.current.handleEvent(event);
      } else {
        savedHandlerRef.current(event);
      }
    };

    var opts = {
      capture: capture,
      passive: passive,
      once: once
    };
    element.addEventListener(eventName, eventListener, opts);
    return function () {
      element.removeEventListener(eventName, eventListener, opts);
    };
  }, [eventName, element, capture, passive, once]);
};

exports.default = useEventListener;
//# sourceMappingURL=event-listener.cjs.development.js.map
