declare type Options = {
    /** The element to listen on. Defaults to `global` (i.e. `window`). */
    element?: EventTarget | null;
    /** Indicates events will be dispatched to the registered listener before being dispatched to any EventTarget beneath it in the DOM tree. */
    capture?: boolean;
    /** Indicates that the handler will never call `preventDefault()`. */
    passive?: boolean;
    /** Indicates that the handler should be invoked at most once after being added. If true, the handler would be automatically removed when invoked. */
    once?: boolean;
};
interface EventListener<T> {
    (evt: T): void;
}
interface EventListenerObject<T> {
    handleEvent(evt: T): void;
}
declare type EventListenerOrEventListenerObject<T> = EventListener<T> | EventListenerObject<T>;
/** Provides a declarative addEventListener */
declare const useEventListener: <T>(eventName: string, handler: EventListenerOrEventListenerObject<T>, options?: Options) => void;
export default useEventListener;
